@@ -8,7 +8,7 @@ from sqlglot.dialects.dialect import Dialect, inline_array_sql
 from sqlglot.errors import ExecuteError
 from sqlglot.executor.context import Context
 from sqlglot.executor.env import ENV
-from sqlglot.executor.table import Table
+from sqlglot.executor.table import RowReader, Table
 from sqlglot.helper import csv_reader
 
 
@@ -89,35 +89,35 @@ class PythonExecutor:
     def scan(self, step, context):
         source = step.source
 
-        if isinstance(source, exp.Expression):
+        if source and isinstance(source, exp.Expression):
             source = source.name or source.alias
 
         condition = self.generate(step.condition)
         projections = self.generate_tuple(step.projections)
 
-        if source in context:
+        if source is None:
+            context, table_iter = self.static()
+        elif source in context:
             if not projections and not condition:
                 return self.context({step.name: context.tables[source]})
             table_iter = context.table_iter(source)
         elif isinstance(step.source, exp.Table) and isinstance(step.source.this, exp.ReadCSV):
             table_iter = self.scan_csv(step)
+            context = next(table_iter)
         else:
-            table_iter = self.scan_table(step)
+            context, table_iter = self.scan_table(step)
 
         if projections:
             sink = self.table(step.projections)
         else:
-            sink = None
+            sink = self.table(context.columns)
 
-        for reader, ctx in table_iter:
-            if sink is None:
-                sink = Table(reader.columns)
-
-            if condition and not ctx.eval(condition):
+        for reader in table_iter:
+            if condition and not context.eval(condition):
                 continue
 
             if projections:
-                sink.append(ctx.eval_tuple(projections))
+                sink.append(context.eval_tuple(projections))
             else:
                 sink.append(reader.row)
 
@@ -126,12 +126,13 @@ class PythonExecutor:
 
         return self.context({step.name: sink})
 
+    def static(self):
+        return self.context({}), [RowReader(())]
+
     def scan_table(self, step):
         table = self.tables.find(step.source)
-
         context = self.context({step.source.alias_or_name: table})
-        for r in table:
-            yield r, context
+        return context, iter(table)
 
     def scan_csv(self, step):
         alias = step.source.alias
@@ -141,6 +142,7 @@ class PythonExecutor:
             columns = next(reader)
             table = Table(columns)
             context = self.context({alias: table})
+            yield context
             types = []
 
             for row in reader:
@@ -151,7 +153,7 @@ class PythonExecutor:
                         except (ValueError, SyntaxError):
                             types.append(str)
                 context.set_row(tuple(t(v) for t, v in zip(types, row)))
-                yield context.table.reader, context
+                yield context.table.reader
 
     def join(self, step, context):
         source = step.name
@@ -349,10 +351,12 @@ class Python(Dialect):
             exp.Alias: lambda self, e: self.sql(e.this),
             exp.Array: inline_array_sql,
             exp.And: lambda self, e: self.binary(e, "and"),
+            exp.Between: lambda self, e: f"{self.sql(e, 'low')} <= {self.sql(e, 'this')} and {self.sql(e, 'this')} <= {self.sql(e, 'high')}",
             exp.Boolean: lambda self, e: "True" if e.this else "False",
             exp.Cast: _cast_py,
             exp.Column: _column_py,
             exp.EQ: lambda self, e: self.binary(e, "=="),
+            exp.NEQ: lambda self, e: self.binary(e, "!="),
             exp.In: lambda self, e: f"{self.sql(e, 'this')} in {self.expressions(e)}",
             exp.Interval: _interval_py,
             exp.Is: lambda self, e: self.binary(e, "is"),
